@@ -11,6 +11,9 @@ class ReplaceColonsTestCase(unittest.TestCase):
     def test_skin_tone(self):
         self.assertEqual('👋🏼', replace_colons(':wave::skin-tone-3:'))
 
+    def test_skin_tone_appended_to_emoji_with_no_skin_tone(self):
+        self.assertEqual('💩🏼', replace_colons(':poop::skin-tone-3:'))
+
     def test_underscore_hyphenated_codes(self):
         self.assertEqual('😙', replace_colons(':kissing_smiling_eyes:'))
         self.assertEqual('😘', replace_colons(':kissing-heart:'))
@@ -24,11 +27,17 @@ class ReplaceColonsTestCase(unittest.TestCase):
         self.assertEqual('👨‍👩‍👦', replace_colons(':man-woman-boy:'))
         self.assertEqual('👨‍🌾', replace_colons(':male-farmer:'))
 
+    def test_zwj_emoji_skin_tone(self):
+        """This tests zwj emojis that also have a skin tone"""
+        self.assertEqual('👨🏼‍🌾', replace_colons(':male-farmer::skin-tone-3:'))
+
     def test_unknown_code(self):
         self.assertEqual('💩💩 :poo:🏼', replace_colons(':hankey::poop: :poo::skin-tone-3:'))
+        self.assertEqual('💩:poo: 🐶 :poo:', replace_colons(':poop::poo: :dog: :poo:'))
 
     def test_strip_unknown_code(self):
         self.assertEqual('💩💩 🏼', replace_colons(':hankey::poop: :poo::skin-tone-3:', strip=True))
+        self.assertEqual('💩 🐶 ', replace_colons(':poop::poo: :dog: :poo:', strip=True))
 
     def test_multiline_sentence(self):
         self.assertEqual("""
